<?php

namespace Litecms\Analytic\Providers;

use Illuminate\Support\ServiceProvider;

class AnalyticServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'analytic');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'analytic');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerAnalytic();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerAnalytic()
    {
        $this->app->bind('analytic', function($app) {
            return new Analytic($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Analytic', 'Lavalite\Analytic\Facades\Analytic');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litecms.analytic', function ($app) {
            return $this->app->make('Litecms\Analytic\Analytic');
        });

                // Bind TransactionLog to repository
        $this->app->bind(
            'Litecms\Analytic\Interfaces\TransactionLogRepositoryInterface',
            \Litecms\Analytic\Repositories\Eloquent\TransactionLogRepository::class
        );

        $this->app->register(\Litecms\Analytic\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Analytic\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Analytic\Providers\RouteServiceProvider::class);
                // $this->app->register(\Litecms\Analytic\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and analytic's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.analytic'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeAnalytic::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.analytic'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/analytic.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/analytic')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/analytic')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
